% Die Test Funktion
f = @(x) cos(x); % Die Funktion f zum Testen
dfdx_exakt = @(x) - sin(x); % Die exakte Ableitung von f
I_exakt = @(a, b) sin(b) - sin(a); % Das exakte Integral von f ueber [a, b]


% Zentrierte Finite Differenzen
x = 0.5;
HS = 1./2.^(0:10);
Err_Ah = [];
Err_Ah_halbe = [];
Err_Atilde = [];
for h=HS
  Ah = finite_difference(f, x, h);
  Ah_halbe = finite_difference(f, x, 0.5*h);
  Atilde = (4.*Ah_halbe - Ah)/3.;
  Err_Ah(end+1) = abs(Ah - dfdx_exakt(x));
  Err_Ah_halbe(end+1) = abs(Ah_halbe - dfdx_exakt(x));
  Err_Atilde(end+1) = abs(Atilde - dfdx_exakt(x));
end
figure(1);
clf;
loglog(HS, Err_Ah, '-+');
hold on;
loglog(HS, Err_Ah_halbe, '-x');
loglog(HS, Err_Atilde, '-d');
grid on;
xlim([HS(end), HS(1)]);
title('Richardson-Extrapolation mit zentrierten finiten Differenzen');
xlabel('h');
ylabel('Err');
legend({'$A(h)$', '$A(h/2)$', '$\tilde{A}(h)$'}, 'Interpreter','latex');
hold off;
% print('-f1', 'richardson_finite_differenzen.eps', '-depsc')


% Summierte Trapezregel
a =0;
b = pi/2;
resolutions = 2.^(0:10);
Err_Ah = [];
Err_Ah_halbe = [];
Err_Atilde = [];
for N=resolutions
  Ah = summtrapezregel(f, a, b, N);
  Ah_halbe = summtrapezregel(f, a, b, 2*N);
  Atilde = (4.*Ah_halbe - Ah)/3.;
  Err_Ah(end+1) = abs(Ah - I_exakt(a, b));
  Err_Ah_halbe(end+1) = abs(Ah_halbe - I_exakt(a, b));
  Err_Atilde(end+1) = abs(Atilde - I_exakt(a, b));
end
figure(2);
clf;
loglog(resolutions, Err_Ah, '-+');
hold on;
loglog(resolutions, Err_Ah_halbe, '-x');
loglog(resolutions, Err_Atilde, '-d');
grid on;
xlim([resolutions(1), resolutions(end)]);
title('Richardson-Extrapolation mit Trapezregel');
xlabel('N');
ylabel('Err');
legend({'$A(N)$', '$A(2N)$', '$\tilde{A}(N)$'}, 'Interpreter','latex');
hold off;
% print('-f2', 'richardson_trapezregel.eps', '-depsc')
