function Q = summtrapezregel(f,a,b,N)
%
% function Q = summtrapezregel(f,a,b,N)
%
% Approximiere das bestimmte Integral von f(x) von a bis b mit der summierten
% Trapezregel.
%
% Parameters: f   ... die zu integrierende Funktion 
%             a,b ... linke/rechte Integrations-Grenzen
%             N   ... Anzahl Teilintervalle
%
% Returns: Q ... Approximation des Integrals

  % Vektor [x_0, x_1, ..., x_N] mit x_0 = a und x_N = b
  x = linspace(a,b,N+1);

  % Teilintervallbreite
  h = (b-a)/N;

  % Summierte Trapezregel
  fx = f(x); % Werte f in x aus
  Q = h/2.*(fx(1) + 2*sum(fx(2:end-1)) + fx(end));

end
